@@ -9,6 +9,7 @@ CREATE TEMP TABLE temp_old_items (
     pid INTEGER,
     name TEXT,
     path TEXT,
+    has_value BOOLEAN,
     value BLOB,
     UNIQUE(pid, name),
     UNIQUE(id, pid),
@@ -17,12 +18,13 @@ CREATE TEMP TABLE temp_old_items (
 CREATE INDEX IF NOT EXISTS temp_old_items_path_idx ON temp_old_items (path);
 
 INSERT INTO temp_old_items
-WITH RECURSIVE old_items (id, pid, name, path, value) AS (
+WITH RECURSIVE old_items (id, pid, name, path, has_value, value) AS (
     SELECT
         nodes.id,
         nodes.pid,
         nodes.name,
         nodes.name,
+        nodes.has_value,
         nodes.value
     FROM nodes WHERE nodes.pid == {old_root}
 
@@ -33,17 +35,19 @@ WITH RECURSIVE old_items (id, pid, name, path, value) AS (
         nodes.pid,
         nodes.name,
         old_items.path || '/' || nodes.name,
+        nodes.has_value,
         nodes.value
     FROM nodes, old_items WHERE old_items.id == nodes.pid
 )
 
-SELECT * FROM old_items;
+SELECT * FROM old_items WHERE has_value;
 
 CREATE TEMP TABLE temp_new_items (
     id INTEGER PRIMARY KEY,
     pid INTEGER,
     name TEXT,
     path TEXT,
+    has_value BOOLEAN,
     value BLOB,
     UNIQUE(pid, name),
     UNIQUE(id, pid),
@@ -52,12 +56,13 @@ CREATE TEMP TABLE temp_new_items (
 CREATE INDEX IF NOT EXISTS temp_new_items_path_idx ON temp_new_items (path);
 
 INSERT INTO temp_new_items
-WITH RECURSIVE new_items (id, pid, name, path, value) AS (
+WITH RECURSIVE new_items (id, pid, name, path, has_value, value) AS (
     SELECT
         nodes.id,
         nodes.pid,
         nodes.name,
         nodes.name,
+        nodes.has_value,
         nodes.value
     FROM nodes WHERE nodes.pid == {new_root}
 
@@ -68,11 +73,12 @@ WITH RECURSIVE new_items (id, pid, name, path, value) AS (
         nodes.pid,
         nodes.name,
         new_items.path || '/' || nodes.name,
+        nodes.has_value,
         nodes.value
     FROM nodes, new_items WHERE new_items.id == nodes.pid
 )
 
-SELECT * FROM new_items;
+SELECT * FROM new_items WHERE has_value;
 
 CREATE TEMP TABLE temp_diff AS
 WITH RECURSIVE diff (
@@ -80,11 +86,13 @@ WITH RECURSIVE diff (
     old_pid,
     old_name,
     old_path,
+    old_has_value,
     old_value,
     new_id,
     new_pid,
     new_name,
     new_path,
+    new_has_value,
     new_value
 ) AS (
     /* FULL OUTER JOIN is not supported, so we have to use two LEFT JOINs :( */
@@ -93,11 +101,13 @@ WITH RECURSIVE diff (
         old.pid,
         old.name,
         old.path,
+        old.has_value,
         old.value,
         new.id,
         new.pid,
         new.name,
         new.path,
+        new.has_value,
         new.value
     FROM
         temp_old_items AS old
@@ -112,11 +122,13 @@ WITH RECURSIVE diff (
         old.pid,
         old.name,
         old.path,
+        old.has_value,
         old.value,
         new.id,
         new.pid,
         new.name,
         new.path,
+        new.has_value,
         new.value
     FROM
         temp_new_items AS new
